@@ -31,15 +31,15 @@ class Robot:
 
     def post_(self, type_, data_):
         url = self.url
+
         r = requests.post(url=url, json=data_, params={"wxid": f"{self.wxid}"})
         # print(r.json())
         return r.json()
 
-    def say(self, msg):
+    def say(self, acceptwxid, msg):
         type_ = "Q0001"
-        data_ = {"type": f"{type_}",
-                 "data": {"type": "1"},
-                 }
+        data_ = {"wxid": f"{acceptwxid}",
+                 "msg": f"{msg}"}
 
         self.post_(type_, data_)
 
@@ -64,7 +64,7 @@ class Robot:
         data_ = {"type": f"{type_}",
                  "data": {"wxid": f"{wxid}",
                           "name": f"{name}",
-                          "author": "浩",
+                          "author": f"{author}",
                           "app": "wx5aa333606550dfd5",
                           "jumpUrl": "https://www.baidu.com/s?ie=utf-8&f=8&rsv_bp=1&tn=baidu&wd=%E4%BD%9C%E8%80%85%E6%B5%A9",
                           "musicUrl": f"{musicUrl}",
@@ -73,6 +73,11 @@ class Robot:
 
         return self.post_(type_, data_)
 
+    def api_get_qq_song_data(self, name):
+        r = requests.get(f"http://114.116.54.227:9999/qqmusic/?name={name}", )
+
+        print(r.json())
+        return r.json()
 
 # a = Robot(url="http://127.0.0.1:7777/DaenWxHook/httpapi/", wxid="wxid_at1vbqt6zgg922")
 # bbb=a.get_friend_list()
@@ -82,4 +87,3 @@ class Robot:
 #     information.run()
 #     print(1)
 #     print(information.q.get())
-
